---
icon: lucide/package
---

# Installation

Pydgey is available on PyPI.

## Install with pip

```bash
pip install pydgey
```

## Development Installation

If you want to contribute to Pydgey, we recommend using `pixi`. See [Contributing](contributing.md) for more information

```bash
git clone https://github.com/leightonpayne/pydgey.git
cd pydgey
pixi install
pixi run dev
```
